.. _abrechnung-dev-architecture:

******************
Architecture
******************

TODO

* PostgreSQL DB, exposed as websocket and http REST API
* various python services (e.g. mail delivery, database cleanup)
* web-client
